@@ -1,7 +1,7 @@
 #import sys
 #sys.path.insert(1, '/Users/caitlin/Documents/Math/PIC16B/pic16bproject')
 #pde-simulation==0.0.1
-from pde-simulation==0.0.1 import transport_equation as te
+from pde_imulation import transport_equation as te
 #from pde_simulation import wave_equation as we
 #from pde_simulation import heat_equation as he
 #from pde_simulation import burgers as be
